@@ -60,12 +60,12 @@ static bool stringLessThan(const QString& p1, const QString& p2)
 
 static void sortByIndexProfileList(QList<Profile::Ptr>& list)
 {
-    qStableSort(list.begin(), list.end(), profileIndexLessThan);
+    std::stable_sort(list.begin(), list.end(), profileIndexLessThan);
 }
 
 static void sortByNameProfileList(QList<Profile::Ptr>& list)
 {
-    qStableSort(list.begin(), list.end(), profileNameLessThan);
+    std::stable_sort(list.begin(), list.end(), profileNameLessThan);
 }
 
 ProfileManager::ProfileManager()
@@ -76,6 +76,7 @@ ProfileManager::ProfileManager()
     , _loadedAllProfiles(false)
     , _loadedFavorites(false)
     , _shortcuts(QMap<QKeySequence, ShortcutData>())
+    , _profileList(nullptr)
 {
     //load fallback profile
     _fallbackProfile = Profile::Ptr(new Profile());
@@ -212,7 +213,7 @@ QStringList ProfileManager::availableProfilePaths() const
     QStringList paths;
     paths += reader.findProfiles();
 
-    qStableSort(paths.begin(), paths.end(), stringLessThan);
+    std::stable_sort(paths.begin(), paths.end(), stringLessThan);
 
     return paths;
 }
@@ -227,7 +228,7 @@ QStringList ProfileManager::availableProfileNames() const
         }
     }
 
-    qStableSort(names.begin(), names.end(), stringLessThan);
+    std::stable_sort(names.begin(), names.end(), stringLessThan);
 
     return names;
 }
@@ -335,7 +336,7 @@ Profile::Ptr ProfileManager::fallbackProfile() const
     return _fallbackProfile;
 }
 
-QString ProfileManager::saveProfile(Profile::Ptr profile)
+QString ProfileManager::saveProfile(const Profile::Ptr &profile)
 {
     ProfileWriter writer;
 
@@ -452,7 +453,7 @@ void ProfileManager::changeProfile(Profile::Ptr profile,
     emit profileChanged(newProfile);
 }
 
-void ProfileManager::addProfile(Profile::Ptr profile)
+void ProfileManager::addProfile(const Profile::Ptr &profile)
 {
     if (_profiles.isEmpty()) {
         _defaultProfile = profile;
@@ -500,7 +501,7 @@ bool ProfileManager::deleteProfile(Profile::Ptr profile)
     return true;
 }
 
-void ProfileManager::setDefaultProfile(Profile::Ptr profile)
+void ProfileManager::setDefaultProfile(const Profile::Ptr &profile)
 {
     Q_ASSERT(_profiles.contains(profile));
 
@@ -529,7 +530,7 @@ QSet<Profile::Ptr> ProfileManager::findFavorites()
 
     return _favorites;
 }
-void ProfileManager::setFavorite(Profile::Ptr profile , bool favorite)
+void ProfileManager::setFavorite(const Profile::Ptr &profile , bool favorite)
 {
     if (!_profiles.contains(profile)) {
         addProfile(profile);
@@ -697,3 +698,10 @@ QKeySequence ProfileManager::shortcut(Profile::Ptr profile) const
     return QKeySequence();
 }
 
+ProfileList *ProfileManager::getProfileList()
+{
+    if (_profileList == nullptr) {
+        _profileList = new ProfileList(true, this);
+    }
+    return _profileList;
+}
