@@ -22,11 +22,9 @@
 #define SESSIONCONTROLLER_H
 
 // Qt
-#include <QList>
 #include <QSet>
 #include <QPointer>
 #include <QString>
-#include <QHash>
 #include <QRegularExpression>
 
 // KDE
@@ -64,9 +62,6 @@ class UrlFilter;
 class FileFilter;
 class EditProfileDialog;
 
-// SaveHistoryTask
-class TerminalCharacterDecoder;
-
 using SessionPtr = QPointer<Session>;
 
 /**
@@ -254,7 +249,7 @@ private Q_SLOTS:
     void monitorActivity(bool monitor);
     void monitorSilence(bool monitor);
     void renameSession();
-    void switchProfile(Profile::Ptr profile);
+    void switchProfile(const Profile::Ptr &profile);
     void handleWebShortcutAction();
     void configureWebShortcuts();
     void sendSignal(QAction *action);
@@ -371,165 +366,6 @@ inline bool SessionController::isValid() const
     return !_session.isNull() && !_view.isNull();
 }
 
-/**
- * Abstract class representing a task which can be performed on a group of sessions.
- *
- * Create a new instance of the appropriate sub-class for the task you want to perform and
- * call the addSession() method to add each session which needs to be processed.
- *
- * Finally, call the execute() method to perform the sub-class specific action on each
- * of the sessions.
- */
-class SessionTask : public QObject
-{
-    Q_OBJECT
-
-public:
-    explicit SessionTask(QObject *parent = nullptr);
-
-    /**
-     * Sets whether the task automatically deletes itself when the task has been finished.
-     * Depending on whether the task operates synchronously or asynchronously, the deletion
-     * may be scheduled immediately after execute() returns or it may happen some time later.
-     */
-    void setAutoDelete(bool enable);
-    /** Returns true if the task automatically deletes itself.  See setAutoDelete() */
-    bool autoDelete() const;
-
-    /** Adds a new session to the group */
-    void addSession(Session *session);
-
-    /**
-     * Executes the task on each of the sessions in the group.
-     * The completed() signal is emitted when the task is finished, depending on the specific sub-class
-     * execute() may be synchronous or asynchronous
-     */
-    virtual void execute() = 0;
-
-Q_SIGNALS:
-    /**
-     * Emitted when the task has completed.
-     * Depending on the task this may occur just before execute() returns, or it
-     * may occur later
-     *
-     * @param success Indicates whether the task completed successfully or not
-     */
-    void completed(bool success);
-
-protected:
-    /** Returns a list of sessions in the group */
-    QList< SessionPtr > sessions() const;
-
-private:
-    bool _autoDelete;
-    QList< SessionPtr > _sessions;
-};
-
-/**
- * A task which prompts for a URL for each session and saves that session's output
- * to the given URL
- */
-class SaveHistoryTask : public SessionTask
-{
-    Q_OBJECT
-
-public:
-    /** Constructs a new task to save session output to URLs */
-    explicit SaveHistoryTask(QObject *parent = nullptr);
-    ~SaveHistoryTask() Q_DECL_OVERRIDE;
-
-    /**
-     * Opens a save file dialog for each session in the group and begins saving
-     * each session's history to the given URL.
-     *
-     * The data transfer is performed asynchronously and will continue after execute() returns.
-     */
-    void execute() Q_DECL_OVERRIDE;
-
-private Q_SLOTS:
-    void jobDataRequested(KIO::Job *job, QByteArray &data);
-    void jobResult(KJob *job);
-
-private:
-    class SaveJob // structure to keep information needed to process
-        // incoming data requests from jobs
-    {
-    public:
-        SessionPtr session; // the session associated with a history save job
-        int lastLineFetched; // the last line processed in the previous data request
-        // set this to -1 at the start of the save job
-
-        TerminalCharacterDecoder *decoder;  // decoder used to convert terminal characters
-        // into output
-    };
-
-    QHash<KJob *, SaveJob> _jobSession;
-};
-
-//class SearchHistoryThread;
-/**
- * A task which searches through the output of sessions for matches for a given regular expression.
- * SearchHistoryTask operates on ScreenWindow instances rather than sessions added by addSession().
- * A screen window can be added to the list to search using addScreenWindow()
- *
- * When execute() is called, the search begins in the direction specified by searchDirection(),
- * starting at the position of the current selection.
- *
- * FIXME - This is not a proper implementation of SessionTask, in that it ignores sessions specified
- * with addSession()
- *
- * TODO - Implementation requirements:
- *          May provide progress feedback to the user when searching very large output logs.
- */
-class SearchHistoryTask : public SessionTask
-{
-    Q_OBJECT
-
-public:
-    /**
-     * Constructs a new search task.
-     */
-    explicit SearchHistoryTask(QObject *parent = nullptr);
-
-    /** Adds a screen window to the list to search when execute() is called. */
-    void addScreenWindow(Session *session, ScreenWindow *searchWindow);
-
-    /** Sets the regular expression which is searched for when execute() is called */
-    void setRegExp(const QRegularExpression &expression);
-    /** Returns the regular expression which is searched for when execute() is called */
-    QRegularExpression regExp() const;
-
-    /** Specifies the direction to search in when execute() is called. */
-    void setSearchDirection(Enum::SearchDirection direction);
-    /** Returns the current search direction.  See setSearchDirection(). */
-    Enum::SearchDirection searchDirection() const;
-
-    /** The line from which the search will be done **/
-    void setStartLine(int line);
-
-    /**
-     * Performs a search through the session's history, starting at the position
-     * of the current selection, in the direction specified by setSearchDirection().
-     *
-     * If it finds a match, the ScreenWindow specified in the constructor is
-     * scrolled to the position where the match occurred and the selection
-     * is set to the matching text.  execute() then returns immediately.
-     *
-     * To continue the search looking for further matches, call execute() again.
-     */
-    void execute() Q_DECL_OVERRIDE;
-
-private:
-    using ScreenWindowPtr = QPointer<ScreenWindow>;
-
-    void executeOnScreenWindow(SessionPtr session, ScreenWindowPtr window);
-    void highlightResult(ScreenWindowPtr window, int findPos);
-
-    QMap< SessionPtr, ScreenWindowPtr > _windows;
-    QRegularExpression _regExp;
-    Enum::SearchDirection _direction;
-    int _startLine;
-};
 }
 
 #endif //SESSIONCONTROLLER_H
